#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.cs.csubak.edu/~dgriffi/proj/frotz/
# source           : ftp://ftp.ifarchive.org/if-archive/infocom/interpreters/frotz/frotz-2.43.tar.gz

# Package name
NAME="frotz"
# Package version
VERSION="2.43"
# Source code URL
SOURCE="ftp://ftp.ifarchive.org/if-archive/infocom/interpreters/frotz/frotz-$VERSION.tar.gz"
# ./configure options
CONFIGOPTIONS="--prefix=/usr"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS BUGS COPYING ChangeLog DUMB HOW_TO_PLAY INSTALL PACKAGING PORTING README README.1st SPEECH TODO"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: frotz - an interpreter for all Infocom and other Z-machine games
$NAME:
$NAME: Frotz is  a Z-Machine interpreter. The Z-machine is a virtual
$NAME: machine designed by Infocom to run all of their text adventures.
$NAME: It went through multiple revisions during the lifetime of the
$NAME: company, and two further revisions (V7 and V8) were created by
$NAME: Graham Nelson after the company's demise.  The  specification is
$NAME: now quite well documented; this version of Frotz supports version
$NAME: 1.0.
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if icons are present. If it's not, download it
if [ -f icons.tar.gz ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/icons.tar.gz
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz
tar xvzf icons.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Frotz
Exec=frotz-launcher
Terminal=false
Type=Application
Categories=Game;Emulator
Icon=frotz
EOF

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
sed -i -e 's,PREFIX = /usr/local,PREFIX = /usr,' Makefile
sed -i -e 's,CONFIG_DIR = /usr/local/etc,CONFIG_DIR = /usr/share/frotz,' Makefile
sed -i -e 's,install -d $(PREFIX)/bin,install -d $(DESTDIR)$(PREFIX)/bin,' Makefile
sed -i -e 's,install -d $(MAN_PREFIX)/man/man6,install -d $(DESTDIR)$(MAN_PREFIX)/man/man6,' Makefile
sed -i -e 's,install -c -m 755 $(BINNAME)$(EXTENSION) $(PREFIX)/bin,install -c -m 755 $(BINNAME)$(EXTENSION) $(DESTDIR)$(PREFIX)/bin,' Makefile
sed -i -e 's,install -c -m 644 doc/$(NAME).6 $(MAN_PREFIX)/man/man6,install -c -m 644 doc/$(NAME).6 $(DESTDIR)$(MAN_PREFIX)/man/man6,' Makefile
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG
mkdir -p $PKG/usr/share/$NAME
cp doc/frotz.conf-* $PKG/usr/share/$NAME

# Create a launch script
cat > $PKG/usr/bin/frotz-launcher << EOF
#!/bin/sh

FILE=\`Xdialog --title "Please choose a frotz story file" --screen-center --fselect /home 35 80 2>&1\`

case \$? in
	0)
		xterm -geometry 100x30 -title "Frotz" -e frotz "\$FILE";;
	1)
		echo "Exiting.";;
	255)
		echo "Exiting.";;
esac
EOF
chmod a+x $PKG/usr/bin/frotz-launcher

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Copy icons to the right place
ICONSIZES="48 32 24 16"
for i in $ICONSIZES; do
	mkdir -p $PKG/usr/share/icons/hicolor/$i\x$i/apps;
	mv $CWD/$NAME-$i.png $PKG/usr/share/icons/hicolor/$i\x$i/apps/$NAME.png;
done;
mkdir -p $PKG/usr/share/icons/hicolor/scalable/apps
cp -a $CWD/$NAME.svg $PKG/usr/share/icons/hicolor/scalable/apps

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
